<script>
import { ref } from "vue";
import {Chart} from "chart.js/auto";
import {MasterMethods} from "@/Store/Functions.js";

export default {
    name: "ChartHome",
    created() {
        this.$page.props.totalSizes.forEach((size, index) => {
            this.totalSizes.push(this.formatBytes(size));
        })
    },
    mounted() {
        this.initializeChart();
    },
    data() {
        return {
            downloadsChart: null,
            totalSizes: []
        };
    },
    methods: {
        convertSizesToNumber(sizes) {
            return sizes.map(size => size / (1024 * 1024 * 1024));
        },
        ...MasterMethods,
        initializeChart() {
            const ctx = document.getElementById('downloadsChart')
            const numericSizes = this.convertSizesToNumber(this.$page.props.totalSizes);
            new Chart(ctx, {
                type: "line",
                data: {
                    labels: this.$page.props.dates,
                    datasets: [
                        {
                            label: "Total Descargado (GB)",
                            data: numericSizes,
                            borderColor: "rgba(75, 192, 192, 1)",
                            backgroundColor: "rgba(75, 192, 192, 0.2)",
                            borderWidth: 1,
                        },
                    ],
                },
                options: {
                    responsive: true,
                    scales: {
                        y: {
                            beginAtZero: true,
                            ticks: {
                                callback: function(value) {
                                    return value.toFixed(2) + ' GB'; // Siempre mostrar en MB
                                }
                            }
                        },
                    },
                },
            });
        }
    }
}
</script>

<template>
    <div class="col-sm-12 col-md-7">
        <canvas id="downloadsChart" width="400" height="200"></canvas>
    </div>
</template>

<style scoped>

</style>
